==> kpogre-1.5.2.tar.gz: kpogre-1.5.2/kpogre/PropertyPages/kpgvoidproppage.h <==
/***************************************************************************
                          kpgvoidproppage  -  description
                             -------------------
    begin                : So led 31 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGVOIDPROPPAGE_H
#define KPGVOIDPROPPAGE_H

// application specific includes
#include "kpgabstractpropertypage.h"

#include "kpgvoidproppagebase.h"

/**
Void Property Page

@author Lumir Vanek
*/
class KPGVoidPropPage : public KPGVoidPropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGVoidPropPage(QWidget *parent = 0, const char *name = 0);
    ~KPGVoidPropPage();

	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return 0; }
};

#endif

==> kpogre-1.8.2.tar.gz: kpogre-1.8.2/kpogre/PropertyPages/kpgvoidproppage.h <==
/***************************************************************************
                          kpgvoidproppage  -  description
                             -------------------
    begin                : So led 31 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGVOIDPROPPAGE_H
#define KPGVOIDPROPPAGE_H

// application specific includes
#include "kpgabstractpropertypage.h"

#include "kpgvoidproppagebase.h"

/**
  * Void Property Page
  *
  * @author Lumir Vanek
  */
class KPGVoidPropPage : public KPGVoidPropPageBase, public KPGAbstractPropertyPage
{
	Q_OBJECT
public:
    KPGVoidPropPage(QWidget *parent);
    ~KPGVoidPropPage();
	
	// Display properties of underlying database object
	virtual void displayProperties();

	// Return Result table for clipboard actions and export. 
	virtual QTable* tableResult() { return 0; }
};

#endif
